@@ -8,11 +8,11 @@ FAMILY = 'test.family'
 registered = pyblish.backend.plugin.registered_paths
 package_path = pyblish.backend.lib.main_package_path()
 plugin_path = os.path.join(package_path, 'backend', 'tests', 'plugins')
-pyblish.backend.plugin.deregister_all()
 
 
 def setup():
     """Disable default plugins and only use test plugins"""
+    pyblish.backend.plugin.deregister_all()
     pyblish.backend.plugin.register_plugin_path(plugin_path)
 
 
@@ -26,18 +26,14 @@ def setup_failing():
 
 
 def setup_duplicate():
-    """Expose duplicate plugins to discovery mechanism"""
+    """Expose duplicate paths to discovery mechanism"""
+    pyblish.backend.plugin.deregister_all()
+
     for copy in ('copy1', 'copy2'):
         path = os.path.join(plugin_path, 'duplicate', copy)
         pyblish.backend.plugin.register_plugin_path(path)
 
 
-def setup_invalid():
-    """Expose invalid plugins to discovery mechanism"""
-    failing_path = os.path.join(plugin_path, 'invalid')
-    pyblish.backend.plugin.register_plugin_path(failing_path)
-
-
 def teardown():
     """Restore previously registered paths"""
     pyblish.backend.plugin.deregister_all()
